import os
import sys
sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))

from yunhu.openapi import Openapi


def main():
    openapi = Openapi("xxx")
    res = openapi.SetBotBoardAll("text", "py测试")
    print(res.content)
    
    
if __name__ == '__main__':
    main()


import setuptools 
 
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
 
setuptools.setup(
    name="yunhu", 
    version="0.0.5", 
    author="yunhu",  
    description="云湖官方Python SDK", #包的简述
    author_email="1114110051@qq.com",    
    long_description=long_description,    #包的详细介绍，一般在README.md文件内
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',    #对python的最低版本要求
)